@@ -33,13 +33,15 @@ class Domoticz(IPlugin):
 #
 	def switchlight(self, jsonInput):
 		bodies = ""
+		entity = jsonInput['outcome']['entities']['body']
+		log.msg("entity :  %s" % (entity))		
 #		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
+#			location = jsonInput['outcome']['entities']['location']['body']
 #		else:
 #			bodies = "pas de lieu"
 #			location= "VIDE"
 #		if jsonInput['outcome']['entities']['on_off']['value'] :
-			on_off = jsonInput['outcome']['entities']['on_off']['value']
+#			on_off = jsonInput['outcome']['entities']['on_off']['value']
 #		else:
 #			bodies = "pas de on/off"
 #			on_off = "VIDE"
